@@ -54,7 +54,7 @@ class Client(object):
             userVans = self.db.urls.find({ "ownerId": ownerId })
             if userVans is None:
                 return "No records found..."
-            return objects.ownerVanities(json.loads(userVans)).ownerVanities
+            return objects.ownerVanities(userVans).ownerVanities
 
         # headers = {
         #     "Authorization": apiKey
